@@ -2,7 +2,7 @@ package Test2::Event;
 use strict;
 use warnings;
 
-our $VERSION = '0.000037';
+our $VERSION = '0.000038';
 
 use Test2::Util::HashBase qw/trace nested/;
 use Test2::Util::ExternalMeta qw/meta get_meta set_meta delete_meta/;
@@ -15,6 +15,8 @@ sub callback { }
 sub terminate { () }
 sub global    { () }
 
+sub summary { ref($_[0]) }
+
 1;
 
 __END__
@@ -137,6 +139,15 @@ True if this event should be considered 'TODO' for diagnostics purposes. This
 essentially means that any message that would go to STDERR will go to STDOUT
 instead so that a harness will hide it outside of verbose mode.
 
+=item $msg = $e->summary
+
+This is intended to be a human readable summary of the event. This should
+ideally only be 1-line long, but you can use multiple lines if necessary. This
+is intended for human consumption, you do not need to make it easy for machines
+to understand.
+
+The default is to simply return the event package name.
+
 =back
 
 =head1 THIRD PARTY META-DATA
