@@ -2,7 +2,7 @@ package Test2::Event::Bail;
 use strict;
 use warnings;
 
-our $VERSION = '0.000037';
+our $VERSION = '0.000038';
 
 use base 'Test2::Event';
 use Test2::Util::HashBase qw{reason};
@@ -21,6 +21,14 @@ sub global { 1 };
 
 sub causes_fail { 1 }
 
+sub summary {
+    my $self = shift;
+    return "Bail out!  " . $self->{+REASON}
+        if $self->{+REASON};
+
+    return "Bail out!";
+}
+
 1;
 
 __END__
