@@ -2,13 +2,19 @@ package Test2::Event::Exception;
 use strict;
 use warnings;
 
-our $VERSION = '0.000037';
+our $VERSION = '0.000038';
 
 use base 'Test2::Event';
 use Test2::Util::HashBase qw{error};
 
 sub causes_fail { 1 }
 
+sub summary {
+    my $self = shift;
+    chomp(my $msg = "Exception: " . $self->{+ERROR});
+    return $msg;
+}
+
 1;
 
 __END__
