@@ -2,7 +2,7 @@ package Test2::Event::Skip;
 use strict;
 use warnings;
 
-our $VERSION = '0.000037';
+our $VERSION = '0.000038';
 
 use base 'Test2::Event::Ok';
 use Test2::Util::HashBase qw{reason};
@@ -15,6 +15,20 @@ sub init {
 
 sub causes_fail { 0 }
 
+sub summary {
+    my $self = shift;
+    my $out = $self->SUPER::summary(@_);
+
+    if (my $reason = $self->reason) {
+        $out .= " (SKIP: $reason)";
+    }
+    else {
+        $out .= " (SKIP)";
+    }
+
+    return $out;
+}
+
 1;
 
 __END__
